pub trait Comparable<K: ?Sized>: Equivalent<K> {
// Required method
fn compare(&self, key: &K) -> Ordering;
}Expand description
Key ordering trait.
This trait allows ordered map lookup to be customized. It has one blanket
implementation that uses the regular solution with Borrow and Ord, just
like BTreeMap does, so that you can pass &str to lookup into a map with
String keys and so on.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".